==> google-displayvideo-clj-0.7.0.jar: com/adgoji/advertisers_assigned_targeting_options/core.clj <==
(ns com.adgoji.advertisers-assigned-targeting-options.core
  (:require
   [com.adgoji.sdk-client-utils.interface :as sdk-client-utils]
   [com.adgoji.spec.interface :as spec]
   [com.adgoji.java-utils.interface :as java-utils]
   [com.adgoji.displayvideo-spec.interface :as displayvideo-spec])
  (:import
   (com.google.api.services.displayvideo.v2 DisplayVideo DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List)
   (com.google.api.services.displayvideo.v2.model AssignedTargetingOption)))

(defn create
  [^DisplayVideo client
   ^long advertiser-id
   ^String targeting-type
   assigned-targeting-option]
  (let [assigned-targeting-option-order-conformed
        (spec/check assigned-targeting-option ::displayvideo-spec/assigned-targeting-option)

        assigned-targeting-option-request
        (java-utils/clj->java AssignedTargetingOption
                              assigned-targeting-option-order-conformed)]
    (-> client
        (.advertisers)
        (.targetingTypes)
        (.assignedTargetingOptions)
        (.create advertiser-id
                 targeting-type
                 assigned-targeting-option-request)
        (sdk-client-utils/execute-and-convert)
        (spec/check ::displayvideo-spec/assigned-targeting-option))))

(defn delete
  [^DisplayVideo client
   ^long advertiser-id
   ^String targeting-type
   ^String assigned-targeting-option-id]
  (-> client
      (.advertisers)
      (.targetingTypes)
      (.assignedTargetingOptions)
      (.delete advertiser-id targeting-type assigned-targeting-option-id)
      (sdk-client-utils/execute-and-convert)))

(defn get-by-id
  [^DisplayVideo client
   ^long advertiser-id
   ^String targeting-type
   ^String assigned-targeting-option-id]
  (-> client
      (.advertisers)
      (.targetingTypes)
      (.assignedTargetingOptions)
      (.get advertiser-id targeting-type assigned-targeting-option-id)
      (sdk-client-utils/execute-and-convert)
      (spec/check ::displayvideo-spec/assigned-targeting-option)))

(defn- fetch-assigned-targeting-options-page
  [^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request
   ^String next-page-token]
  (-> request
      (.setPageToken next-page-token)
      (sdk-client-utils/execute-and-convert)))

(defn get-list
  [^DisplayVideo client
   ^long advertiser-id
   ^String targeting-type
   {:keys [order-by filter-expr limit]}]
  (let [request (-> client
                    (.advertisers)
                    (.targetingTypes)
                    (.assignedTargetingOptions)
                    (.list advertiser-id targeting-type))]
    (when order-by
      (.setOrderBy ^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request order-by))
    (when filter-expr
      (.setFilter ^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request filter-expr))
    (-> (sdk-client-utils/execute-and-convert-paginated
         (partial fetch-assigned-targeting-options-page request)
         :assigned-targeting-options
         limit)
        (spec/check ::displayvideo-spec/assigned-targeting-options))))

==> google-displayvideo-clj-0.11.2.jar: com/adgoji/advertisers_assigned_targeting_options/core.clj <==
(ns com.adgoji.advertisers-assigned-targeting-options.core
  (:require
   [com.adgoji.sdk-client-utils.interface :as sdk-client-utils]
   [com.adgoji.spec.interface :as spec]
   [com.adgoji.java-utils.interface :as java-utils]
   [com.adgoji.displayvideo-spec.interface :as displayvideo-spec])
  (:import
   (com.google.api.services.displayvideo.v2 DisplayVideo DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List)
   (com.google.api.services.displayvideo.v2.model AssignedTargetingOption)))

(defn create
  [^DisplayVideo client advertiser-id targeting-type
   assigned-targeting-option]
  (let [assigned-targeting-option-order-conformed
        (spec/check assigned-targeting-option ::displayvideo-spec/assigned-targeting-option)

        assigned-targeting-option-request
        (java-utils/clj->java AssignedTargetingOption
                              assigned-targeting-option-order-conformed)]
    (-> client
        (.advertisers)
        (.targetingTypes)
        (.assignedTargetingOptions)
        (.create (long advertiser-id)
                 targeting-type
                 assigned-targeting-option-request)
        (sdk-client-utils/execute-and-convert)
        (spec/check ::displayvideo-spec/assigned-targeting-option))))

(defn delete
  [^DisplayVideo client
   advertiser-id
   targeting-type
   assigned-targeting-option-id]
  (-> client
      (.advertisers)
      (.targetingTypes)
      (.assignedTargetingOptions)
      (.delete (long advertiser-id)
               targeting-type
               assigned-targeting-option-id)
      (sdk-client-utils/execute-and-convert)))

(defn get-by-id
  [^DisplayVideo client
   advertiser-id
   targeting-type
   assigned-targeting-option-id]
  (-> client
      (.advertisers)
      (.targetingTypes)
      (.assignedTargetingOptions)
      (.get (long advertiser-id)
            targeting-type
            assigned-targeting-option-id)
      (sdk-client-utils/execute-and-convert)
      (spec/check ::displayvideo-spec/assigned-targeting-option)))

(defn- fetch-assigned-targeting-options-page
  [^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request
   ^String next-page-token]
  (-> request
      (.setPageToken next-page-token)
      (sdk-client-utils/execute-and-convert)))

(defn get-list
  [^DisplayVideo client advertiser-id targeting-type
   {:keys [order-by filter-expr limit]}]
  (let [request (-> client
                    (.advertisers)
                    (.targetingTypes)
                    (.assignedTargetingOptions)
                    (.list (long advertiser-id) targeting-type))]
    (when order-by
      (.setOrderBy ^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request order-by))
    (when filter-expr
      (.setFilter ^DisplayVideo$Advertisers$TargetingTypes$AssignedTargetingOptions$List request filter-expr))
    (-> (sdk-client-utils/execute-and-convert-paginated
         (partial fetch-assigned-targeting-options-page request)
         :assigned-targeting-options
         limit)
        (spec/check ::displayvideo-spec/assigned-targeting-options))))
